OverlayDecoration class
Constructors
-
OverlayDecoration({BoxShape shape = BoxShape.rectangle, bool applyGlassEffect = true, double glassSigmaXY = 2.0, Color? backgroundColor, BorderRadius? borderRadius, List<
BoxShadow> ? boxShadow, Gradient? gradient, Border? border}) -
const
Properties
- applyGlassEffect → bool
-
Whether to apply a glass blur effect behind the overlay.
final
- backgroundColor → Color?
-
Background color for the overlay.
final
- border → Border?
-
Optional border drawn around the overlay.
final
- borderRadius → BorderRadius?
-
Decoration options for the magnifier overlay.
final
-
boxShadow
→ List<
BoxShadow> ? -
Optional shadow applied behind the overlay.
final
- glassSigmaXY → double
-
Blur sigma for the glass effect when enabled.
final
- gradient → Gradient?
-
Optional gradient used to paint the overlay background.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shape → BoxShape
-
Shape of the overlay: rectangle or circle.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited